Dependencies + install command
Quick start code snippet
Full API reference (Engine, Scene, GameObject, Camera, Mesh, Material, Texture, Lighting, Collision, HUD, Inventory)
Controls reference (FlyCamera, OrbitCamera)
A note on the auto_collision parameter